@@ -25,6 +25,20 @@ import unidecode
 from majormode.perseus.model.enum import Enum
 
 
+class IncompleteFullNameException(Exception):
+    """
+    If none of the first name or the last name parts are in the full name
+    of a person
+    """
+
+
+class InvalidLexicalNameOrderException(Exception):
+    """
+    Indicate that the full name of a person is not formatted according to
+    the lexical order of the person's culture
+    """
+
+
 LexicalNameOrder = Enum(
     # The family name comes first, while the given name comes last. This
     # order is primarily used in East Asia (for example in China, Japan and
@@ -49,7 +63,6 @@ LexicalNameOrder = Enum(
 # The World Atlas of Language Structures Online.
 # Leipzig: Max Planck Institute for Evolutionary Anthropology.
 # (Available online at http://wals.info/chapter/86, Accessed on 2021-03-24.)
-
 LEXICAL_NAME_ORDERS = {
     'aar': LexicalNameOrder.EasternOrder,
     'aba': LexicalNameOrder.EasternOrder,
@@ -286,6 +299,7 @@ LEXICAL_NAME_ORDERS = {
     'dds': LexicalNameOrder.EasternOrder,
     'der': LexicalNameOrder.EasternOrder,
     'des': LexicalNameOrder.EasternOrder,
+    'deu': LexicalNameOrder.EasternOrder,
     'dga': LexicalNameOrder.EasternOrder,
     'dgb': LexicalNameOrder.EasternOrder,
     'dgo': LexicalNameOrder.WesternOrder,
@@ -1335,7 +1349,7 @@ def format_full_name(
     :raise ValueError: When a full name is provided, while none of the
         words of the first name or the last name is part of this full name.
     """
-    lexical_name_order = LEXICAL_NAME_ORDERS[locale.to_string()] or LexicalNameOrder.WesternOrder
+    lexical_name_order = LEXICAL_NAME_ORDERS.get(locale.to_string()) or LexicalNameOrder.WesternOrder
 
     first_name = normalize_name(first_name)
     last_name = normalize_name(last_name)
@@ -1354,7 +1368,8 @@ def format_full_name(
             else __rfind(full_name_components, first_name_components)
         if indices is None:
             if strict:
-                raise ValueError(f'None of the first name words "{first_name}" has been found in the full name "{full_name}"')
+                raise IncompleteFullNameException(
+                    f'None of the first name parts "{first_name}" has been found in the full name "{full_name}"')
             return full_name
 
         first_name_lowest_index, first_name_greatest_index = indices
@@ -1366,7 +1381,8 @@ def format_full_name(
             else __find(full_name_components, last_name_components)
         if indices is None:
             if strict:
-                raise ValueError(f'None of the last name words "{last_name}" has been found in the full name "{full_name}"')
+                raise IncompleteFullNameException(
+                    f'None of the last name parts "{last_name}" has been found in the full name "{full_name}"')
             return full_name
 
         last_name_lowest_index, last_name_greatest_index = indices
@@ -1386,7 +1402,8 @@ def format_full_name(
         if (lexical_name_order == LexicalNameOrder.EasternOrder and last_name_lowest_index > first_name_lowest_index) or \
            (lexical_name_order == LexicalNameOrder.WesternOrder and last_name_lowest_index < first_name_lowest_index):
             if strict:
-                raise ValueError(f'The parts of the full name "{full_name}" are not written in the expected order')
+                raise InvalidLexicalNameOrderException(
+                    f'The parts of the full name "{full_name}" are not written in the expected order')
             return full_name
 
         if lexical_name_order == LexicalNameOrder.WesternOrder:
